]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - command.c
dbtool -> audio file selector renaming
[paraslash.git] / command.c
index 3fe6e5db008a6d2cfdc767cbd8e04321ea739391..7a258f2e4c4e9792ff0275e868947b0c1bc0af34 100644 (file)
--- a/command.c
+++ b/command.c
@@ -75,11 +75,11 @@ static struct server_command cmd_struct[] = {
 .name = "cdt",
 .handler = com_cdt,
 .perms = DB_READ | DB_WRITE,
-.description = "change database tool",
-.synopsis = "cdt [name_of_new_dbtool]",
+.description = "change the current audio file selector",
+.synopsis = "cdt [new_selector]",
 .help =
-"Deactivate current dbtool and activate name_of_new_dbtool. If no\n"
-"argument was given, print the current database tool.\n"
+"Shutdown the current selector and activate new_selector. If no\n"
+"argument was given, print the name of the current selector.\n"
 },
 
 {
@@ -732,7 +732,7 @@ static struct server_command *get_cmd_ptr(char *name, char **handler)
                                *handler = para_strdup("para_server"); /* server commands */
                        return cmd;
                }
/* not found, look for dbtool commands */
        mmd_lock();
        if (handler)
                *handler = make_message("the %s database tool", dblist[mmd->dbt_num].name);
@@ -732,7 +732,7 @@ static struct server_command *get_cmd_ptr(char *name, char **handler)
                        return cmd;
                }
-       /* not found, look for dbtool commands */
+       /* not found, look for commands supported by the current selector */
        mmd_lock();
        if (handler)